==> ngsolve-6.2.2501-cp312-cp312-manylinux_2_28_x86_64.whl: ngsolve-6.2.2501.data/data/lib/python3.12/site-packages/ngsolve/config/config.py <==
def _cmake_to_bool(s):
    return s.upper() not in ['', '0','FALSE','OFF','N','NO','IGNORE','NOTFOUND']

is_python_package    = _cmake_to_bool("TRUE")

BUILD_STUB_FILES     = _cmake_to_bool("ON")
BUILD_UMFPACK        = _cmake_to_bool("")
ENABLE_UNIT_TESTS    = _cmake_to_bool("OFF")
INSTALL_DEPENDENCIES = _cmake_to_bool("OFF")
USE_CCACHE           = _cmake_to_bool("ON")
USE_HYPRE            = _cmake_to_bool("OFF")
USE_LAPACK           = _cmake_to_bool("ON")
USE_MKL              = _cmake_to_bool("ON")
USE_MUMPS            = _cmake_to_bool("OFF")
USE_PARDISO          = _cmake_to_bool("OFF")
USE_UMFPACK          = _cmake_to_bool("OFF")

NETGEN_DIR = "/opt/_internal/cpython-3.12.8"

NGSOLVE_COMPILE_DEFINITIONS         = "HAVE_NETGEN_SOURCES;HAVE_DLFCN_H;HAVE_CXA_DEMANGLE;USE_TIMEOFDAY;TCL;LAPACK;USE_PARDISO;NGS_PYTHON"
NGSOLVE_COMPILE_DEFINITIONS_PRIVATE = "USE_MKL"
NGSOLVE_COMPILE_INCLUDE_DIRS        = ""
NGSOLVE_COMPILE_OPTIONS             = "$<$<COMPILE_LANGUAGE:CXX>:-std=c++17>;-DMAX_SYS_DIM=3"

NGSOLVE_INSTALL_DIR_PYTHON   = "lib/python3.12/site-packages"
NGSOLVE_INSTALL_DIR_BIN      = "bin"
NGSOLVE_INSTALL_DIR_LIB      = "lib/python3.12/site-packages/netgen_mesher.libs"
NGSOLVE_INSTALL_DIR_INCLUDE  = "include/netgen"
NGSOLVE_INSTALL_DIR_CMAKE    = "lib/cmake/ngsolve"
NGSOLVE_INSTALL_DIR_RES      = "share"

NGSOLVE_VERSION = "6.2.2501"
NGSOLVE_VERSION_GIT = "v6.2.2501-0-g59eb8fef6"
NGSOLVE_VERSION_PYTHON = "6.2.2501"

NGSOLVE_VERSION_MAJOR = "6"
NGSOLVE_VERSION_MINOR = "2"
NGSOLVE_VERSION_TWEAK = "0"
NGSOLVE_VERSION_PATCH = "2501"
NGSOLVE_VERSION_HASH = "g59eb8fef6"

CMAKE_CXX_COMPILER           = "/opt/rh/gcc-toolset-14/root/usr/bin/c++"
CMAKE_CUDA_COMPILER          = ""
CMAKE_C_COMPILER             = "/opt/rh/gcc-toolset-14/root/usr/bin/cc"
CMAKE_LINKER                 = "/opt/rh/gcc-toolset-14/root/usr/bin/ld"
CMAKE_INSTALL_PREFIX         = "/builds/ngsolve/ngsolve/_skbuild/linux-x86_64-3.12/cmake-install"
CMAKE_CXX_COMPILER_LAUNCHER  = "/usr/bin/ccache"

version = NGSOLVE_VERSION_GIT

MKL_LINK = "sdl"

def get_cmake_dir():
    import os.path as p
    d_python = p.dirname(p.dirname(p.dirname(__file__)))
    py_to_cmake = p.relpath(
            NGSOLVE_INSTALL_DIR_CMAKE,
            NGSOLVE_INSTALL_DIR_PYTHON
            )
    return p.normpath(p.join(d_python,py_to_cmake))

==> ngsolve-6.2.2504.post12.dev0-cp312-cp312-manylinux_2_28_x86_64.whl: ngsolve-6.2.2504.post12.dev0.data/data/lib/python3.12/site-packages/ngsolve/config/config.py <==
def _cmake_to_bool(s):
    return s.upper() not in ['', '0','FALSE','OFF','N','NO','IGNORE','NOTFOUND']

is_python_package    = _cmake_to_bool("TRUE")

BUILD_STUB_FILES     = _cmake_to_bool("ON")
BUILD_UMFPACK        = _cmake_to_bool("")
ENABLE_UNIT_TESTS    = _cmake_to_bool("OFF")
INSTALL_DEPENDENCIES = _cmake_to_bool("OFF")
USE_CCACHE           = _cmake_to_bool("ON")
USE_HYPRE            = _cmake_to_bool("OFF")
USE_LAPACK           = _cmake_to_bool("ON")
USE_MKL              = _cmake_to_bool("ON")
USE_MUMPS            = _cmake_to_bool("OFF")
USE_PARDISO          = _cmake_to_bool("OFF")
USE_UMFPACK          = _cmake_to_bool("OFF")

NETGEN_DIR = "/opt/_internal/cpython-3.12.8"

NGSOLVE_COMPILE_DEFINITIONS         = "HAVE_NETGEN_SOURCES;HAVE_DLFCN_H;HAVE_CXA_DEMANGLE;USE_TIMEOFDAY;TCL;LAPACK;USE_PARDISO;NGS_PYTHON"
NGSOLVE_COMPILE_DEFINITIONS_PRIVATE = "USE_MKL"
NGSOLVE_COMPILE_INCLUDE_DIRS        = ""
NGSOLVE_COMPILE_OPTIONS             = "$<$<COMPILE_LANGUAGE:CXX>:-std=c++17>;-DMAX_SYS_DIM=3"

NGSOLVE_INSTALL_DIR_PYTHON   = "lib/python3.12/site-packages"
NGSOLVE_INSTALL_DIR_BIN      = "bin"
NGSOLVE_INSTALL_DIR_LIB      = "lib/python3.12/site-packages/netgen_mesher.libs"
NGSOLVE_INSTALL_DIR_INCLUDE  = "include/netgen"
NGSOLVE_INSTALL_DIR_CMAKE    = "lib/cmake/ngsolve"
NGSOLVE_INSTALL_DIR_RES      = "share"

NGSOLVE_VERSION = "6.2.2504-12-gd2e909551"
NGSOLVE_VERSION_GIT = "v6.2.2504-12-gd2e909551"
NGSOLVE_VERSION_PYTHON = "6.2.2504.post12.dev0"

NGSOLVE_VERSION_MAJOR = "6"
NGSOLVE_VERSION_MINOR = "2"
NGSOLVE_VERSION_TWEAK = "12"
NGSOLVE_VERSION_PATCH = "2504"
NGSOLVE_VERSION_HASH = "gd2e909551"

CMAKE_CXX_COMPILER           = "/opt/rh/gcc-toolset-14/root/usr/bin/c++"
CMAKE_CUDA_COMPILER          = ""
CMAKE_C_COMPILER             = "/opt/rh/gcc-toolset-14/root/usr/bin/cc"
CMAKE_LINKER                 = "/opt/rh/gcc-toolset-14/root/usr/bin/ld"
CMAKE_INSTALL_PREFIX         = "/builds/ngsolve/ngsolve/_skbuild/linux-x86_64-3.12/cmake-install"
CMAKE_CXX_COMPILER_LAUNCHER  = "/usr/bin/ccache"

version = NGSOLVE_VERSION_GIT

MKL_LINK = "sdl"

def get_cmake_dir():
    import os.path as p
    d_python = p.dirname(p.dirname(p.dirname(__file__)))
    py_to_cmake = p.relpath(
            NGSOLVE_INSTALL_DIR_CMAKE,
            NGSOLVE_INSTALL_DIR_PYTHON
            )
    return p.normpath(p.join(d_python,py_to_cmake))
